/*
 +=========================================================================================================================================+
 | Project : Video / Audio Switcher                                                                                                        |                                                                           |                                                                                                                
 | Author  : Richard VK4XRL, Mike G7GTN                                                                                                    |
 | IDE     : Compiled here in Ardunio IDE Version 1.0.5                                                                                    |
 | Version : See below                                                                                                                     |
 | Date    : October 2016                                                                                                                  |
 +=========================================================================================================================================+
                                                                                                                                                                                                    
 I/O Pin Usage:
                                                   Ardunio NANO Physical Pins
            
            TSOP2838 38KHz IR Remote Sensor          - Digital Pin D12
            Speaker or Peizo Sounder                 - Digital Pin D11            
            74HC4351 Video / Audio Multiplexer S0    - Digital Pin D2
            74HC4351 Video / Audio Multiplexer S1    - Digital Pin D3	
	    74HC4351 Video / Audio Multiplexer S2    - Digital Pin D4
            74HC4351 Latch Enable Number 1           - Digital Pin D5
            74HC4351 Latch Enable Number 2           - Digital Pin D6
            LCD via I2C Backpack on address (0x27)   - Analog A4 & A5
            Maxim DS3231 RTC address (0X68) via I2C  - Analog A4 & A5   
            Serial RX/TX                             - Digital Pin D0 & D1   
 
 Revisions:

 V2.04 Code for CQ-DATV Magazine Digital World Article Part 2

 Additional facility for a second Video switch channel. The first acts as a preview and on pressing a remote buttton the second switch
 takes this source to air (TX). Allowing you to now preview video sources before live presentation.

 Additional External Code Libraries Required, these are all supplied within this ZIP file as part of the software download.

 External Code Libraries Required:

 https://github.com/z3t0/Arduino-IRremote
 https://github.com/switchdoclabs/RTC_SDL_DS3231_ARDUINO 

 Once decompressed install these into your Ardunuio IDEs library location. Typically on a Windows based machine this will be 
 program Files (x86) Ardunio\libraries
 
 Once installed close and then restart the Ardunio IDE if you had this open at the time for the libraries to be correctly recognised.

 Further information on installing Libraries is available from the Ardunio website using the following link:-
 https://www.arduino.cc/en/Guide/Libraries
 
 User changes:

 If you wish to change the remote buttons that we have selected, then you will require the HEX codes for these. A simple way to discover
 these are to upload the irtest.ino file we have prepared and then start the Ardunio IDE Serial Monitor set to 9600 baud. On decoding 
 buttons the HEX code will be shown. Within the function void translateIR() you will find these codes being used. Each as per done here 
 need to be pre-fixed with (zero) 0x (IR remotes hex number discovered)

 Sony TV code pages:
 
 Sony remotes (universal clone types) have many different code pages that you can select from. This might cause you an issue to make 
 sure your codes are the same as the ones we have discovered (and used) to help you discover these unique hexadecimal codes by pressing
 a button on the remote control any key will be shown on the Serial Monitor. With these noted down (or using copy and paste) you can easily 
 make changes to the code as mentioned above in User Changes. 

 +=========================================================================================================================================+ 

 Designated IR Remote Control Buttons:
 
 1- 8 Select      Select Source Multiplexer channel
 0                Test Switch (Dual) Video Multiplexers - 5 second delay between all channel switching   
 VOL+          	  Send Video Source To Transmit Multiplexer
 Channel Up (+)   Show Real Time Clock
 Channel Down (-) Show Temperature Display
 Power Button     Software Reset Ardunio Nano Module
  
 +=========================================================================================================================================+
              
*/

const char Version [] = "V2.04";

//================================== LCD text strings for users designated connected Video Sources ==
//
// If you wish to label your own sources and the text for one is a different size then all strings 
// should be padded to 13 characters using spaces, this stops the display from showing characters
// from previous strings. The count starts from Zero up to 14 to give us 13 available characters.
//
char Str1[14] = "Video 1";
char Str2[14] = "Video 2";
char Str3[14] = "Video 3";
char Str4[14] = "Video 4";
char Str5[14] = "Video 5";
char Str6[14] = "Video 6";
char Str7[14] = "Video 7";
char Str8[14] = "Video 8";
//===================================================================================================

// User setting options
//#define I2Cscan                                       // Check for all I2C devices when uncommented
//#define SETRTC                                        // Set clock for first time then comment out this line and re-download code
#define TONES                                           // For IR Remote Button acknowledge tone

// Define Digital I/O Pins for 74HC4351 Video & Audio Multiplexer
#define MATRIXS0 2
#define MATRIXS1 3
#define MATRIXS2 4 
#define LATCH_ENABLE1 5                                 // Pin set high
#define LATCH_ENABLE2 6                                 // Transmit Multiplexer

// Sony IR Remote
#include <IRremote.h>                           	// IR Decoding Library
int RECV_PIN = 12;      		          	// 38KHz IR detector to Digital Pin 12
IRrecv irrecv(RECV_PIN);
decode_results results;
                        	                                 
 // include I2C LCD library
 #include <Wire.h>
 #include <LCD.h>
 #include <LiquidCrystal_I2C.h>
 #define I2C_ADDR 0x27   				// I2C LCD Hexadecimal Address Of eBay PCF8574A Backpack Device
 #define BACKLIGHT_PIN     3
 #define En_pin  2
 #define Rw_pin  1
 #define Rs_pin  0
 #define D4_pin  4
 #define D5_pin  5
 #define D6_pin  6
 #define D7_pin  7
 LiquidCrystal_I2C lcd(I2C_ADDR,En_pin,Rw_pin,Rs_pin,D4_pin,D5_pin,D6_pin,D7_pin);

 // Custom termo LCD character
 byte termo[8] = 
 {
    B00100,
    B01010,
    B01010,
    B01110,
    B01110,
    B11111,
    B11111,
    B01110
 };

// Eeprom Addresses
#define CHANNEL_ADDRESS_PV 2  				// Eeprom address for saved user channel
#define CHANNEL_TRANSMIT_TX 4                           // TX Source Channel
#include <EEPROM.h>	        	    		// Read & Write to ATMEGA328P Eeprom space

// DS3231 Realtime Clock Library
#include <DS3231.h>                        		// Dallas I2C RTC Library
 
DS3231 Clock;
bool Century=false;
bool h12;
bool PM;
byte ADay, AHour, AMinute, ASecond, ABits;
bool ADy, A12h, Apm;
byte year, month, date, DoW, hour, minute, second;

//--------------------------------------------------------------------------------------- 
// GENERAL HARDWARE SETUP
//--------------------------------------------------------------------------------------- 
void setup()
{			
  pinMode(11, OUTPUT);                                   // Audio tones on pin D11
  setiodirection();                          	         // Set 74HC4351 I/O pin direction
  latch1polarity();                                      // Control Voltage polarity of 1ST enable latch
  latch2polarity();					 //     "      "        "    of 2ND enable latch 
  Serial.begin(9600);	 	       		         // Change if wish for faster
  Serial.flush(); 
      Wire.begin( );
      lcd.begin (16,2); 
      lcd.createChar(1,termo);	
      lcd.setBacklightPin(BACKLIGHT_PIN,POSITIVE);	// Switch on LCD backlight
      lcd.setBacklight(HIGH);
      lcd.home();                                   				 
  irrecv.enableIRIn();           		        // Start 38KHz IR decoder  
  titlemsg();						// Projects title message
  #if defined I2Cscan                                   // Look for any connected I2C devices
      scanbus();
  #endif      
  #if defined SETRTC					// Once Date & Time are set comment out top user define and re-download the code
      Wire.begin();
      Clock.setSecond(20);      			// Set the required seconds 
      Clock.setMinute(24);        			// Set the required minutes 
      Clock.setHour(13);         			// Set the required hour 
      Clock.setDoW(1);          			// Set the required day of the week from 1-7
      Clock.setDate(9);         			// Set the required date of the month
      Clock.setMonth(10);        			// Set the required month of the year from 1-12
      Clock.setYear(16);        			// Set the required year (Only the Last two digits need to be entered)            
  #endif  
}

//--------------------------------------------------------------------------------------- 
// TX & PV LCD text strings
void TX_String()
{
    lcd.setCursor(0,0);                                 // TX message
    lcd.print("TX:");
}
void PV_String()
{
    lcd.setCursor(0,1);                                 // PV messsage
    lcd.print("PV:");
}  

//--------------------------------------------------------------------------------------- 
//                           Switch Video / Audio Channels
//
// 74HC4351 Datasheet
// http://pdf1.alldatasheet.com/datasheet-pdf/view/15623/PHILIPS/74HC4351D.html  
//
//  ---------------|------|------|-------
//  Video Channel  |  S0  |  S1  |  S2
//  Audio Channel  |      |      |
//  ---------------|------|------|-------
//        (1)      |  L   |  L   |  L
//        (2)      |  H   |  L   |  L
//        (3)      |  L   |  H   |  L
//        (4)      |  H   |  H   |  L
//        (5)      |  L   |  L   |  H
//        (6)      |  H   |  L   |  H
//        (7)      |  L   |  H   |  H
//        (8)      |  H   |  H   |  H
//
//--------------------------------------------------------------------------------------- 
void chan1()
{
 digitalWrite(MATRIXS0, LOW);                   	// Logic Levels sent to Multiplexer(s)  
 digitalWrite(MATRIXS1, LOW);
 digitalWrite(MATRIXS2, LOW);
 digitalWrite(LATCH_ENABLE1,HIGH);
 PV_String();
     lcd.setCursor(3,1);                         
     lcd.print(Str1);
 int value;
 value=1;
 // Save users current multiplexer channel number to EEprom
 EEPROM.write(CHANNEL_ADDRESS_PV, value); 
}

void chan2()
{
 digitalWrite(MATRIXS0, HIGH);                   	  
 digitalWrite(MATRIXS1, LOW);
 digitalWrite(MATRIXS2, LOW);
 digitalWrite(LATCH_ENABLE1,HIGH);
 PV_String();
     lcd.setCursor(3,1);
     lcd.print(Str2);
 int value;
 value=2;
 EEPROM.write(CHANNEL_ADDRESS_PV, value);
}

void chan3()
{
 digitalWrite(MATRIXS0, LOW);                   	  
 digitalWrite(MATRIXS1, HIGH);
 digitalWrite(MATRIXS2, LOW);
 digitalWrite(LATCH_ENABLE1,HIGH);
 PV_String();
     lcd.setCursor(3,1);
     lcd.print(Str3);
 int value;
 value=3;
 EEPROM.write(CHANNEL_ADDRESS_PV, value);  
}

void chan4()
{
 digitalWrite(MATRIXS0, HIGH);                   	  
 digitalWrite(MATRIXS1, HIGH);
 digitalWrite(MATRIXS2, LOW);
 digitalWrite(LATCH_ENABLE1,HIGH);
 PV_String();
     lcd.setCursor(3,1);
     lcd.print(Str4);
 int value;
 value=4;
 EEPROM.write(CHANNEL_ADDRESS_PV, value);  
}

void chan5()
{
 digitalWrite(MATRIXS0, LOW);                   	 
 digitalWrite(MATRIXS1, LOW);
 digitalWrite(MATRIXS2, HIGH);
 digitalWrite(LATCH_ENABLE1,HIGH);
 PV_String();
     lcd.setCursor(3,1);
     lcd.print(Str5);
 int value;
 value=5;
 EEPROM.write(CHANNEL_ADDRESS_PV, value);  
}

void chan6()
{
 digitalWrite(MATRIXS0, HIGH);                   	  
 digitalWrite(MATRIXS1, LOW);
 digitalWrite(MATRIXS2, HIGH);
 digitalWrite(LATCH_ENABLE1,HIGH); 
 PV_String();
     lcd.setCursor(3,1);
     lcd.print(Str6);   
 int value;
 value=6;
 EEPROM.write(CHANNEL_ADDRESS_PV, value);  
}

void chan7()
{
 digitalWrite(MATRIXS0, LOW);                   	 
 digitalWrite(MATRIXS1, HIGH);
 digitalWrite(MATRIXS2, HIGH);
 digitalWrite(LATCH_ENABLE1,HIGH); 
 PV_String();
     lcd.setCursor(3,1);
     lcd.print(Str7);
 int value;
 value=7;
 EEPROM.write(CHANNEL_ADDRESS_PV, value);  
}

void chan8()
{
 digitalWrite(MATRIXS0, HIGH);                   	 
 digitalWrite(MATRIXS1, HIGH);
 digitalWrite(MATRIXS2, HIGH);
 digitalWrite(LATCH_ENABLE1,HIGH);
 PV_String();
     lcd.setCursor(3,1);
     lcd.print(Str8);
 int value;
 value=8;
 EEPROM.write(CHANNEL_ADDRESS_PV, value);  
}

// Test switching channels - 5 second delay between each
// Then defaults back to Channel 1
void testchannels()
{
   
   digitalWrite(LATCH_ENABLE2,HIGH);    			// Enable latch to TX channel
   chan1();
   TX_String();
   lcd.print(Str1);
   #if defined TONES
       beep(50);
   #endif 
   delay(5000);
   chan2();
   TX_String();
   lcd.print(Str2);
   #if defined TONES
       beep(50);
   #endif 
   delay(5000);
   chan3();
   TX_String();
   lcd.print(Str3); 
   #if defined TONES
       beep(50);
   #endif  
   delay(5000);
   chan4();
   TX_String();
   lcd.print(Str4); 
   #if defined TONES
       beep(50);
   #endif  
   delay(5000);
   chan5();
   TX_String();
   lcd.print(Str5); 
   #if defined TONES
       beep(50);
   #endif 
   delay(5000);
   chan6();
   TX_String(); 
   lcd.print(Str6);
   #if defined TONES
       beep(50);
   #endif 
   delay(5000);
   chan7();
   TX_String();
   lcd.print(Str7);
   #if defined TONES
       beep(50);
   #endif 
   delay(5000);
   chan8();
   TX_String();
   lcd.print(Str8);
   #if defined TONES
       beep(50);
   #endif 
   delay(5000);
   #if defined TONES
       beep(50);
   #endif 
   lcd.setCursor(0,0);
   TX_String();
   lcd.print(Str1);
   chan1();                             // Now switch back to channel 1
   int addr = 4;
   digitalWrite(LATCH_ENABLE2,LOW);     // Set back LOW to stop further Latching from preview channel
   EEPROM.write(addr, 1);     
}

// Get TX Channel
// Pull Latch Enable2 High on Video Selection
void pushchannel()
{
  int a = 2;
  int value;
  int addr = 4;
  value = EEPROM.read(a);
  //Serial.print(value);
  switch(value)
  {
    case 1:
      TX_String();    
      lcd.print(Str1);
      EEPROM.write(addr, 1);  
      break;
    case 2: 
      TX_String();
      lcd.print(Str2);
      EEPROM.write(addr, 2);
      break;
    case 3:       
      TX_String();    
      lcd.print(Str3); 
      EEPROM.write(addr, 3);
      break;    
    case 4:
      TX_String();    
      lcd.print(Str4); 
      EEPROM.write(addr, 4);
      break;     
    case 5:       
      TX_String();   
      lcd.print(Str5); 
      EEPROM.write(addr, 5);
      break;     
    case 6:
      TX_String();    
      lcd.print(Str6); 
      EEPROM.write(addr, 6);
      break;  
    case 7:       
      TX_String();    
      lcd.print(Str7); 
      EEPROM.write(addr, 7);
      break;
    case 8:       
      TX_String();    
      lcd.print(Str8); 
      EEPROM.write(addr, 8);
      break;        
  }
digitalWrite(LATCH_ENABLE2,HIGH);      // Enable latch to TX channel
delay(1000);                           // 1 second latch enable delay 
digitalWrite(LATCH_ENABLE2,LOW);       // Set back LOW to stop further latching from preview channel

}

// Get back and display TX Channel
void getbacktx()
{
  int a = 4;
  int value;
  value = EEPROM.read(a);  
  //Serial.print(value);
  switch(value)
  {
    case 1:
      TX_String();    
      lcd.print(Str1);  
      break;
    case 2: 
      TX_String();
      lcd.print(Str2);
      break;
    case 3:       
      TX_String();    
      lcd.print(Str3); 
      break;    
    case 4:
      TX_String();    
      lcd.print(Str4); 
      break;     
    case 5:       
      TX_String();   
      lcd.print(Str5); 
      break;     
    case 6:
      TX_String();    
      lcd.print(Str6); 
      break;  
    case 7:       
      TX_String();    
      lcd.print(Str7); 
      break;
    case 8:       
      TX_String();    
      lcd.print(Str8); 
      break;        
  }   
}  

//--------------------------------------------------------------------------------------- 
// Software reset
//--------------------------------------------------------------------------------------- 
void(*resetFunction) (void) = 0;

//--------------------------------------------------------------------------------------- 
// Read multiplexer channel number from Eeprom and go back to this
// If first run then default to channel 1
//--------------------------------------------------------------------------------------- 
void checkeeprom(uint8_t level)
{
  // If Eeprom is unwritten (0xFF)
  if (level==255)
      chan1();      					// Need a default value if first run
  switch(level)
  {
    case 1:           
      chan1();          
      break;
    case 2:
      chan2();  
      break;
    case 3:           
      chan3();
      break;    
    case 4:
      chan4();          
      break;     
    case 5:       
      chan5();    
      break;     
    case 6:                
      chan6();
      break;  
    case 7:           
      chan7();           
      break;
    case 8:               
      chan8();
      break;        
  }
}

//--------------------------------------------------------------------------------------- 
// Take action based on IR code received
// Hex codes are from the decoded Sony Remote Buttons
// This used Sony TV Remote Page Code 0140
//--------------------------------------------------------------------------------------- 
void translateIR()  
{ 
  switch(results.value)
  {
    case 0x10:  					// IR 1 Button
      #if defined TONES
       beep(50);
      #endif
      chan1();      
      break;          
    case 0x810: 					// IR 2 Button 
      #if defined TONES
       beep(50);
      #endif
      chan2();
      break;
    case 0x410: 					// IR 3 Button
      #if defined TONES
       beep(50);
      #endif
      chan3();
      break;
    case 0xC10:			        		// IR 4 Button
     #if defined TONES
       beep(50);
     #endif
      chan4();
      break;
    case 0x210:  					// IR 5 Button
      #if defined TONES
       beep(50);
      #endif
      chan5();
      break;
    case 0xA10: 					// IR 6 Button
      #if defined TONES
       beep(50);
      #endif
      chan6();      
      break;
    case 0x610: 					// IR 7 Button
      #if defined TONES
       beep(50);
      #endif
      chan7();      
      break;
    case 0xe10: 					// IR 8 Button
      #if defined TONES
       beep(50);
      #endif
      chan8();   
      break;
    case 0x910:						// IR 0 Button - Test switch channels
      #if defined TONES
       beep(50); 
      #endif
      testchannels();
      break;
    case 0x490:                                         // IR VOL+ 
      #if defined TONES
       beep(50);
      #endif 
      pushchannel();
      break;
    case 0x090:	                      	        	// IR Channel Up         
      #if defined TONES
       beep(50);
      #endif
      gettime();                                        // Show DS3231 Realtime Clock      
      break;
    case 0x890:						// IR Channel Down
      #if defined TONES
       beep(50);
      #endif
      gettemp();                                        // Show DS3231 Temp Reading
      break;   
    case 0xA90:						// IR Power Button		
      #if defined TONES
       beep(50);
      #endif
      resetFunction();					// Reset Nano Module
      break;
 }  
}

//--------------------------------------------------------------------------------------- 
// 74HC4351 MULTIPLEXER I/O SETUP
// http://pdf1.alldatasheet.com/datasheet-pdf/view/15623/PHILIPS/74HC4351D.html
//--------------------------------------------------------------------------------------- 
void setiodirection()
{
  pinMode(MATRIXS0, OUTPUT);                    	// Set 74HC4351 Multiplexer S0-S2 Control pin direction
  pinMode(MATRIXS1, OUTPUT);      
  pinMode(MATRIXS2, OUTPUT);   
  pinMode(LATCH_ENABLE1,OUTPUT);		        // Preview 74HC4351 Pin 11
  pinMode(LATCH_ENABLE2,OUTPUT);                        // Transmit 74HC4351 Pin 11
}

// Set polarity of the Enable line (Pin 11) on 1st Latch
void latch1polarity()
{
   digitalWrite(LATCH_ENABLE1,HIGH); 
}

// LOW polarity of the Enable line (Pin 11) on 2nd Latch
// Set as HIGH to load device on receiving IR remote command
void latch2polarity()
{
   digitalWrite(LATCH_ENABLE2,LOW); 
}

// Default Video channel 1
void defaultchannel()
{
 digitalWrite(MATRIXS0, LOW);                   	// Logic Levels sent to Multiplexer(s)  
 digitalWrite(MATRIXS1, LOW);
 digitalWrite(MATRIXS2, LOW);
 digitalWrite(LATCH_ENABLE1,HIGH);
 digitalWrite(LATCH_ENABLE2,HIGH);                     // Enable Latch to TX channel
 TX_String();
     lcd.print(Str1);
 PV_String();
     lcd.print(Str1);
 // Save users current multiplexer channel number to Eeprom
 int value;
 int transmit;
 value=1;
 transmit=1;
 EEPROM.write(CHANNEL_ADDRESS_PV, value); 
 EEPROM.write(CHANNEL_TRANSMIT_TX, transmit);         // Store value of Transmit Channel                           
 digitalWrite(LATCH_ENABLE2,LOW);                     // Disable TX Latch      
}

//--------------------------------------------------------------------------------------- 
// LCD title message
//--------------------------------------------------------------------------------------- 
void titlemsg()
{
    lcd.clear();
    lcd.setCursor(0,0);
    lcd.print("CQ-DATV Switcher");
    lcd.setCursor (0,1);        			 
    lcd.print("Project");  
    lcd.setCursor(8,1);
    lcd.print(Version);
    delay(1600);                                          // Delay to read
    lcd.clear();
    defaultchannel();                                     // Start TX & PV on default channel 1
}

//---------------------------------------------------------------------------------------
// Scan for bus connected I2C devices on Analog A4 & A5
// Comment out top #define I2Cscan if not required
//---------------------------------------------------------------------------------------
void scanbus()
{
  Serial.println ("[I2C Scanning]");
  byte count = 0;
  Wire.begin();
  for (byte i = 1; i < 127; i++)                	// I2C address range
  {
    Wire.beginTransmission (i);
    if (Wire.endTransmission () == 0)
      {
      Serial.print ("Found device at address: ");
      Serial.print ("Decimal ");
      Serial.print (i, DEC);
      Serial.print (" Hexadecimal(0x");
      Serial.print (i, HEX);
      Serial.println (")");
      count++;
      delay (1);  
      } 
  } 
  Serial.print ("Found ");
  Serial.print (count, DEC);
  Serial.println (" I2C device(s).");
  Serial.println ("[Finished Scan]");     
}  

//---------------------------------------------------------------------------------------
// DS3231 RTC Display - previous video/audio channel number is saved to Eeprom
// On timeout is re-displayed on LCD
//---------------------------------------------------------------------------------------
void gettime()
{  
     int second,minute,hour,date,month,year,DOW; 
     second=Clock.getSecond();
     minute=Clock.getMinute();
     hour=Clock.getHour(h12, PM);
     date=Clock.getDate();
     month=Clock.getMonth(Century);
     year=Clock.getYear();
     DOW=Clock.getDoW(); 
     
     lcd.clear();
     lcd.setCursor(5,1);                                 
     // Account for when hour value is less than 10 and pad with a preceeding zero
     if (hour<10)
     {
       lcd.print("0");
     }
     // Show actual Hour value  
     lcd.print(hour,DEC);
          
     lcd.print(":");					 // Show range seperator	
     // Account for when minute value is less than 10 and pad with a preceeding zero
     if (minute<10)
     {
       lcd.print("0");
     }
     // Show actual minute value
     lcd.print(minute,DEC);
     if (hour<12){
             
		//is now(AM) 
                lcd.setCursor(10,1);  
		lcd.print(" AM ");
     }
     if (hour>11){
             
		//is now (PM) 
                lcd.setCursor(10,1);  
		lcd.print(" PM ");
     }
     showdayname();                                     // Range being from (1 - 7)
     delay(2500);                                       // Delay to read time display                             
     lcd.clear();
     checkeeprom(EEPROM.read(CHANNEL_ADDRESS_PV));      // Check for last user channel     
     getbacktx();                                       // Get back TX channel string
}     

// Show the day of week as an english name
// Returns Sunday (1) through Saturday (7)
void showdayname()
{
  int DOW; 
  DOW=Clock.getDoW();
  switch(DOW)
  {
    case 1: 
      lcd.setCursor(4,0);                                // 2 chars in line 1               
      lcd.print("SUNDAY ");
      break;
    case 2:      
      lcd.setCursor(4,0);  
      lcd.print("MONDAY ");
      break; 
    case 3:
      lcd.setCursor(4,0);  
      lcd.print("TUESDAY ");
      break; 
    case 4:  
      lcd.setCursor(4,0);  
      lcd.print("WEDNESDAY ");
      break;  
    case 5: 
      lcd.setCursor(4,0);  
      lcd.print("THURSDAY ");
      break;   
    case 6: 
      lcd.setCursor(4,0);  
      lcd.print("FRIDAY "); 
      break;  
    case 7:      
      lcd.setCursor(4,0);  
      lcd.print("SATURDAY ");
      break;  
  }
}  

// Read & display temperature from internal DS3231 register
// https://datasheets.maximintegrated.com/en/ds/DS3231.pdf Datasheet page 15 
void gettemp()
{
    int temperature; 
    temperature=Clock.getTemperature();                // Get Temp value from RTC  
    lcd.clear();
    lcd.print("TEMPERATURE IS");
    lcd.setCursor(0,1);
    lcd.print("CURRENTLY");
    lcd.setCursor(10, 1);
    lcd.write(1);                                      // Show custom character
    lcd.setCursor(12, 1);
    lcd.print(temperature); 
    lcd.print((char)223);                              // Use HD44780 chips degree symbol 
    delay(2500);                                       // Delay to read temp display                             
    lcd.clear();
    checkeeprom(EEPROM.read(CHANNEL_ADDRESS_PV));      // Check for last user channel 
    getbacktx();                                       // Get back TX channel string
}

// IR Remote Button audio acknowledgement tone
void beep(unsigned char delayms)
{
  analogWrite(11, 20);                                 // Change second number for different tone                
  delay(delayms);          
  analogWrite(11, 0);                                  // Turn off
  delay(delayms);            
}  

//--------------------------------------------------------------------------------------- 
// MAIN CONTROL LOOP
//--------------------------------------------------------------------------------------- 
void loop()
{ 
  if (irrecv.decode(&results))  			// Sony IR signal received 
  {
    translateIR();
    for (int z=0; z<2; z++)     			// skip the 2nd and 3rd IR signal repeats
    {
      irrecv.resume();          			// receive next value
    }
  }
}

